JSON protocol types for communication between the terminal and script subprocesses.
Scripts read ScriptEvent objects from stdin (one JSON object per line) and write
ScriptCommand objects to stdout (one JSON object per line).
Structs
- Script
Event - An event sent from the terminal to a script subprocess (via stdin).
Enums
- Script
Command - A command sent from a script subprocess to the terminal (via stdout).
- Script
Event Data - Event-specific payload data.